@@ -28,8 +28,7 @@ typedef struct
   gint     dummy1;
   gint     dummy2;
   gint     dummy3;
-  gboolean time_seed;
-  guint    seed_value;
+  guint    seed;
 } PlugInVals;
 
 typedef struct
